# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from access_server_connector.models.override_batch_in import OverrideBatchIn  # noqa: E501

class TestOverrideBatchIn(unittest.TestCase):
    """OverrideBatchIn unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> OverrideBatchIn:
        """Test OverrideBatchIn
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `OverrideBatchIn`
        """
        model = OverrideBatchIn()  # noqa: E501
        if include_optional:
            return OverrideBatchIn(
                portal_id = 56,
                created_by = 56,
                items = [
                    access_server_connector.models.override_item.OverrideItem(
                        member_id = 56, 
                        resource_type = 'course', 
                        resource_id = 56, 
                        is_active = True, 
                        rule = null, )
                    ]
            )
        else:
            return OverrideBatchIn(
                portal_id = 56,
                items = [
                    access_server_connector.models.override_item.OverrideItem(
                        member_id = 56, 
                        resource_type = 'course', 
                        resource_id = 56, 
                        is_active = True, 
                        rule = null, )
                    ],
        )
        """

    def testOverrideBatchIn(self):
        """Test OverrideBatchIn"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from access_server_connector.models.node_access_out import NodeAccessOut  # noqa: E501

class TestNodeAccessOut(unittest.TestCase):
    """NodeAccessOut unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> NodeAccessOut:
        """Test NodeAccessOut
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `NodeAccessOut`
        """
        model = NodeAccessOut()  # noqa: E501
        if include_optional:
            return NodeAccessOut(
                resource_type = 'course',
                resource_id = 56,
                state = 'available',
                allowed = True,
                available_at = 56,
                expires_at = 56,
                lock_reason = 'launch_date',
                winning_layer = 'override',
                reasons = [
                    56
                    ],
                expired_message = '',
                children = [
                    access_server_connector.models.node_access_out.NodeAccessOut(
                        resource_type = 'course', 
                        resource_id = 56, 
                        state = 'available', 
                        allowed = True, 
                        available_at = 56, 
                        expires_at = 56, 
                        lock_reason = null, 
                        winning_layer = null, 
                        reasons = [
                            56
                            ], 
                        expired_message = '', 
                        children = [
                            access_server_connector.models.node_access_out.NodeAccessOut(
                                resource_type = 'course', 
                                resource_id = 56, 
                                state = 'available', 
                                allowed = True, 
                                available_at = 56, 
                                expires_at = 56, 
                                lock_reason = null, 
                                winning_layer = null, 
                                reasons = [
                                    56
                                    ], 
                                expired_message = '', 
                                children = , )
                            ], )
                    ]
            )
        else:
            return NodeAccessOut(
                resource_type = 'course',
                resource_id = 56,
                state = 'available',
                allowed = True,
                available_at = 56,
                expires_at = 56,
                lock_reason = 'launch_date',
                winning_layer = 'override',
                reasons = [
                    56
                    ],
        )
        """

    def testNodeAccessOut(self):
        """Test NodeAccessOut"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# flake8: noqa

# import apis into api package
from access_server_connector.api.access_api import AccessApi
from access_server_connector.api.admin_api import AdminApi
from access_server_connector.api.individual_api import IndividualApi
from access_server_connector.api.ownership_api import OwnershipApi
from access_server_connector.api.packages_api import PackagesApi




# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class ReasonStatus(str, Enum):
    """
    ReasonStatus
    """

    """
    allowed enum values
    """
    ACTIVE = 'active'
    SETTLED = 'settled'
    LAPSED = 'lapsed'
    DEFAULTED = 'defaulted'
    REVOKED = 'revoked'

    @classmethod
    def from_json(cls, json_str: str) -> ReasonStatus:
        """Create an instance of ReasonStatus from a JSON string"""
        return ReasonStatus(json.loads(json_str))





# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt
from access_server_connector.models.reason_kind import ReasonKind
from access_server_connector.models.reason_status import ReasonStatus

class MemberOwnershipOut(BaseModel):
    """
    A member's hold on a package — for the 'who has access to this package' roster.  # noqa: E501
    """
    member_id: StrictInt = Field(...)
    reason_id: StrictInt = Field(...)
    access_package_id: StrictInt = Field(...)
    kind: ReasonKind = Field(...)
    status: ReasonStatus = Field(...)
    granted_at: StrictInt = Field(...)
    is_test: StrictBool = Field(...)
    period_end: Optional[StrictInt] = Field(...)
    grace_until: Optional[StrictInt] = Field(...)
    __properties = ["member_id", "reason_id", "access_package_id", "kind", "status", "granted_at", "is_test", "period_end", "grace_until"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> MemberOwnershipOut:
        """Create an instance of MemberOwnershipOut from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if period_end (nullable) is None
        # and __fields_set__ contains the field
        if self.period_end is None and "period_end" in self.__fields_set__:
            _dict['period_end'] = None

        # set to None if grace_until (nullable) is None
        # and __fields_set__ contains the field
        if self.grace_until is None and "grace_until" in self.__fields_set__:
            _dict['grace_until'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> MemberOwnershipOut:
        """Create an instance of MemberOwnershipOut from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return MemberOwnershipOut.parse_obj(obj)

        _obj = MemberOwnershipOut.parse_obj({
            "member_id": obj.get("member_id"),
            "reason_id": obj.get("reason_id"),
            "access_package_id": obj.get("access_package_id"),
            "kind": obj.get("kind"),
            "status": obj.get("status"),
            "granted_at": obj.get("granted_at"),
            "is_test": obj.get("is_test"),
            "period_end": obj.get("period_end"),
            "grace_until": obj.get("grace_until")
        })
        return _obj





# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from access_server_connector.models.resolve_out import ResolveOut  # noqa: E501

class TestResolveOut(unittest.TestCase):
    """ResolveOut unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResolveOut:
        """Test ResolveOut
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResolveOut`
        """
        model = ResolveOut()  # noqa: E501
        if include_optional:
            return ResolveOut(
                root = access_server_connector.models.node_access_out.NodeAccessOut(
                    resource_type = 'course', 
                    resource_id = 56, 
                    state = 'available', 
                    allowed = True, 
                    available_at = 56, 
                    expires_at = 56, 
                    lock_reason = null, 
                    winning_layer = null, 
                    reasons = [
                        56
                        ], 
                    expired_message = '', 
                    children = [
                        access_server_connector.models.node_access_out.NodeAccessOut(
                            resource_type = 'course', 
                            resource_id = 56, 
                            state = 'available', 
                            allowed = True, 
                            available_at = 56, 
                            expires_at = 56, 
                            lock_reason = null, 
                            winning_layer = null, 
                            reasons = [
                                56
                                ], 
                            expired_message = '', 
                            children = [
                                
                                ], )
                        ], ),
                next_transition = 56
            )
        else:
            return ResolveOut(
                root = access_server_connector.models.node_access_out.NodeAccessOut(
                    resource_type = 'course', 
                    resource_id = 56, 
                    state = 'available', 
                    allowed = True, 
                    available_at = 56, 
                    expires_at = 56, 
                    lock_reason = null, 
                    winning_layer = null, 
                    reasons = [
                        56
                        ], 
                    expired_message = '', 
                    children = [
                        access_server_connector.models.node_access_out.NodeAccessOut(
                            resource_type = 'course', 
                            resource_id = 56, 
                            state = 'available', 
                            allowed = True, 
                            available_at = 56, 
                            expires_at = 56, 
                            lock_reason = null, 
                            winning_layer = null, 
                            reasons = [
                                56
                                ], 
                            expired_message = '', 
                            children = [
                                
                                ], )
                        ], ),
                next_transition = 56,
        )
        """

    def testResolveOut(self):
        """Test ResolveOut"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from access_server_connector.models.wrapped_response_public_package_out import WrappedResponsePublicPackageOut  # noqa: E501

class TestWrappedResponsePublicPackageOut(unittest.TestCase):
    """WrappedResponsePublicPackageOut unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> WrappedResponsePublicPackageOut:
        """Test WrappedResponsePublicPackageOut
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `WrappedResponsePublicPackageOut`
        """
        model = WrappedResponsePublicPackageOut()  # noqa: E501
        if include_optional:
            return WrappedResponsePublicPackageOut(
                done = True,
                result = access_server_connector.models.public_package_out.PublicPackageOut(
                    id = 56, 
                    title = '', 
                    payment_type = '', 
                    sales_page_url = '', 
                    is_active = True, )
            )
        else:
            return WrappedResponsePublicPackageOut(
                result = access_server_connector.models.public_package_out.PublicPackageOut(
                    id = 56, 
                    title = '', 
                    payment_type = '', 
                    sales_page_url = '', 
                    is_active = True, ),
        )
        """

    def testWrappedResponsePublicPackageOut(self):
        """Test WrappedResponsePublicPackageOut"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from access_server_connector.models.access_order_event import AccessOrderEvent  # noqa: E501

class TestAccessOrderEvent(unittest.TestCase):
    """AccessOrderEvent unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AccessOrderEvent:
        """Test AccessOrderEvent
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AccessOrderEvent`
        """
        model = AccessOrderEvent()  # noqa: E501
        if include_optional:
            return AccessOrderEvent(
                event_id = '',
                occurred_at = 56,
                portal_id = 56,
                member_id = 56,
                reason_kind = 'order',
                product = access_server_connector.models.event_product.EventProduct(
                    provider = '', 
                    external_product_id = '', 
                    marketplace_product_id = 56, ),
                access_package_ids = [
                    56
                    ],
                order = access_server_connector.models.event_order.EventOrder(
                    external_order_id = '', 
                    payment_type = '', 
                    is_test = True, ),
                status = 'active',
                status_reason = '',
                subscription = access_server_connector.models.event_subscription.EventSubscription(
                    external_subscription_id = '', 
                    current_period_end = 56, 
                    grace_until = 56, )
            )
        else:
            return AccessOrderEvent(
                event_id = '',
                occurred_at = 56,
                portal_id = 56,
                member_id = 56,
                status = 'active',
        )
        """

    def testAccessOrderEvent(self):
        """Test AccessOrderEvent"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.0+2647093479"

# Define package exports
__all__ = [
    "AccessApi",
    "AdminApi",
    "IndividualApi",
    "OwnershipApi",
    "PackagesApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "AccessMode",
    "AccessOrderEvent",
    "AccessResultOut",
    "Binding",
    "CheckIn",
    "ConsumeOut",
    "CourseStructure",
    "CourseSummaryOut",
    "CourseTreeOut",
    "DeactivateIn",
    "EventOrder",
    "EventProduct",
    "EventSubscription",
    "ExpiryType",
    "GrantIn",
    "HTTPValidationError",
    "HealthOut",
    "IdOut",
    "LessonStructure",
    "LocationInner",
    "LockReason",
    "MemberOwnershipOut",
    "ModuleStructure",
    "ModuleTreeOut",
    "NodeAccessOut",
    "OverrideBatchIn",
    "OverrideItem",
    "OverrideOut",
    "OwnedPackageOut",
    "OwnershipReasonOut",
    "PackageDetailOut",
    "PackageIn",
    "PackageOut",
    "PackagePatchIn",
    "PackageRuleIn",
    "ProductLinkIn",
    "ProductLinkOut",
    "PublicPackageOut",
    "ReasonKind",
    "ReasonStatus",
    "ResolveIn",
    "ResolveOut",
    "ResourceNodeIn",
    "ResourceType",
    "RuleBody",
    "RuleBodyOut",
    "RuleOut",
    "State",
    "TreeIn",
    "UnlockSpec",
    "UnlockType",
    "ValidationError",
    "WinningLayer",
    "WrappedResponseAccessResultOut",
    "WrappedResponseConsumeOut",
    "WrappedResponseCourseTreeOut",
    "WrappedResponseHealthOut",
    "WrappedResponseIdOut",
    "WrappedResponseInt",
    "WrappedResponseListCourseSummaryOut",
    "WrappedResponseListMemberOwnershipOut",
    "WrappedResponseListOverrideOut",
    "WrappedResponseListOwnedPackageOut",
    "WrappedResponseListOwnershipReasonOut",
    "WrappedResponseListPackageOut",
    "WrappedResponseListProductLinkOut",
    "WrappedResponseListRuleOut",
    "WrappedResponsePackageDetailOut",
    "WrappedResponsePublicPackageOut",
    "WrappedResponseResolveOut",
    "WrappedResponseWrittenOut",
    "WrittenOut",
]

# import apis into sdk package
from access_server_connector.api.access_api import AccessApi as AccessApi
from access_server_connector.api.admin_api import AdminApi as AdminApi
from access_server_connector.api.individual_api import IndividualApi as IndividualApi
from access_server_connector.api.ownership_api import OwnershipApi as OwnershipApi
from access_server_connector.api.packages_api import PackagesApi as PackagesApi

# import ApiClient
from access_server_connector.api_response import ApiResponse as ApiResponse
from access_server_connector.api_client import ApiClient as ApiClient
from access_server_connector.configuration import Configuration as Configuration
from access_server_connector.exceptions import OpenApiException as OpenApiException
from access_server_connector.exceptions import ApiTypeError as ApiTypeError
from access_server_connector.exceptions import ApiValueError as ApiValueError
from access_server_connector.exceptions import ApiKeyError as ApiKeyError
from access_server_connector.exceptions import ApiAttributeError as ApiAttributeError
from access_server_connector.exceptions import ApiException as ApiException

# import models into sdk package
from access_server_connector.models.access_mode import AccessMode as AccessMode
from access_server_connector.models.access_order_event import AccessOrderEvent as AccessOrderEvent
from access_server_connector.models.access_result_out import AccessResultOut as AccessResultOut
from access_server_connector.models.binding import Binding as Binding
from access_server_connector.models.check_in import CheckIn as CheckIn
from access_server_connector.models.consume_out import ConsumeOut as ConsumeOut
from access_server_connector.models.course_structure import CourseStructure as CourseStructure
from access_server_connector.models.course_summary_out import CourseSummaryOut as CourseSummaryOut
from access_server_connector.models.course_tree_out import CourseTreeOut as CourseTreeOut
from access_server_connector.models.deactivate_in import DeactivateIn as DeactivateIn
from access_server_connector.models.event_order import EventOrder as EventOrder
from access_server_connector.models.event_product import EventProduct as EventProduct
from access_server_connector.models.event_subscription import EventSubscription as EventSubscription
from access_server_connector.models.expiry_type import ExpiryType as ExpiryType
from access_server_connector.models.grant_in import GrantIn as GrantIn
from access_server_connector.models.http_validation_error import HTTPValidationError as HTTPValidationError
from access_server_connector.models.health_out import HealthOut as HealthOut
from access_server_connector.models.id_out import IdOut as IdOut
from access_server_connector.models.lesson_structure import LessonStructure as LessonStructure
from access_server_connector.models.location_inner import LocationInner as LocationInner
from access_server_connector.models.lock_reason import LockReason as LockReason
from access_server_connector.models.member_ownership_out import MemberOwnershipOut as MemberOwnershipOut
from access_server_connector.models.module_structure import ModuleStructure as ModuleStructure
from access_server_connector.models.module_tree_out import ModuleTreeOut as ModuleTreeOut
from access_server_connector.models.node_access_out import NodeAccessOut as NodeAccessOut
from access_server_connector.models.override_batch_in import OverrideBatchIn as OverrideBatchIn
from access_server_connector.models.override_item import OverrideItem as OverrideItem
from access_server_connector.models.override_out import OverrideOut as OverrideOut
from access_server_connector.models.owned_package_out import OwnedPackageOut as OwnedPackageOut
from access_server_connector.models.ownership_reason_out import OwnershipReasonOut as OwnershipReasonOut
from access_server_connector.models.package_detail_out import PackageDetailOut as PackageDetailOut
from access_server_connector.models.package_in import PackageIn as PackageIn
from access_server_connector.models.package_out import PackageOut as PackageOut
from access_server_connector.models.package_patch_in import PackagePatchIn as PackagePatchIn
from access_server_connector.models.package_rule_in import PackageRuleIn as PackageRuleIn
from access_server_connector.models.product_link_in import ProductLinkIn as ProductLinkIn
from access_server_connector.models.product_link_out import ProductLinkOut as ProductLinkOut
from access_server_connector.models.public_package_out import PublicPackageOut as PublicPackageOut
from access_server_connector.models.reason_kind import ReasonKind as ReasonKind
from access_server_connector.models.reason_status import ReasonStatus as ReasonStatus
from access_server_connector.models.resolve_in import ResolveIn as ResolveIn
from access_server_connector.models.resolve_out import ResolveOut as ResolveOut
from access_server_connector.models.resource_node_in import ResourceNodeIn as ResourceNodeIn
from access_server_connector.models.resource_type import ResourceType as ResourceType
from access_server_connector.models.rule_body import RuleBody as RuleBody
from access_server_connector.models.rule_body_out import RuleBodyOut as RuleBodyOut
from access_server_connector.models.rule_out import RuleOut as RuleOut
from access_server_connector.models.state import State as State
from access_server_connector.models.tree_in import TreeIn as TreeIn
from access_server_connector.models.unlock_spec import UnlockSpec as UnlockSpec
from access_server_connector.models.unlock_type import UnlockType as UnlockType
from access_server_connector.models.validation_error import ValidationError as ValidationError
from access_server_connector.models.winning_layer import WinningLayer as WinningLayer
from access_server_connector.models.wrapped_response_access_result_out import WrappedResponseAccessResultOut as WrappedResponseAccessResultOut
from access_server_connector.models.wrapped_response_consume_out import WrappedResponseConsumeOut as WrappedResponseConsumeOut
from access_server_connector.models.wrapped_response_course_tree_out import WrappedResponseCourseTreeOut as WrappedResponseCourseTreeOut
from access_server_connector.models.wrapped_response_health_out import WrappedResponseHealthOut as WrappedResponseHealthOut
from access_server_connector.models.wrapped_response_id_out import WrappedResponseIdOut as WrappedResponseIdOut
from access_server_connector.models.wrapped_response_int import WrappedResponseInt as WrappedResponseInt
from access_server_connector.models.wrapped_response_list_course_summary_out import WrappedResponseListCourseSummaryOut as WrappedResponseListCourseSummaryOut
from access_server_connector.models.wrapped_response_list_member_ownership_out import WrappedResponseListMemberOwnershipOut as WrappedResponseListMemberOwnershipOut
from access_server_connector.models.wrapped_response_list_override_out import WrappedResponseListOverrideOut as WrappedResponseListOverrideOut
from access_server_connector.models.wrapped_response_list_owned_package_out import WrappedResponseListOwnedPackageOut as WrappedResponseListOwnedPackageOut
from access_server_connector.models.wrapped_response_list_ownership_reason_out import WrappedResponseListOwnershipReasonOut as WrappedResponseListOwnershipReasonOut
from access_server_connector.models.wrapped_response_list_package_out import WrappedResponseListPackageOut as WrappedResponseListPackageOut
from access_server_connector.models.wrapped_response_list_product_link_out import WrappedResponseListProductLinkOut as WrappedResponseListProductLinkOut
from access_server_connector.models.wrapped_response_list_rule_out import WrappedResponseListRuleOut as WrappedResponseListRuleOut
from access_server_connector.models.wrapped_response_package_detail_out import WrappedResponsePackageDetailOut as WrappedResponsePackageDetailOut
from access_server_connector.models.wrapped_response_public_package_out import WrappedResponsePublicPackageOut as WrappedResponsePublicPackageOut
from access_server_connector.models.wrapped_response_resolve_out import WrappedResponseResolveOut as WrappedResponseResolveOut
from access_server_connector.models.wrapped_response_written_out import WrappedResponseWrittenOut as WrappedResponseWrittenOut
from access_server_connector.models.written_out import WrittenOut as WrittenOut



# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictInt, conlist
from access_server_connector.models.access_mode import AccessMode
from access_server_connector.models.binding import Binding
from access_server_connector.models.expiry_type import ExpiryType
from access_server_connector.models.unlock_type import UnlockType

class RuleBodyOut(BaseModel):
    """
    An override's optional rule body (all fields nullable — sparse).  # noqa: E501
    """
    access_mode: Optional[AccessMode] = Field(...)
    unlock_type: Optional[UnlockType] = Field(...)
    unlock_days: Optional[StrictInt] = Field(...)
    unlock_weekday: Optional[StrictInt] = Field(...)
    unlock_weekdays: Optional[conlist(StrictInt)] = Field(...)
    unlock_date: Optional[StrictInt] = Field(...)
    expiry_type: Optional[ExpiryType] = Field(...)
    expiry_days: Optional[StrictInt] = Field(...)
    expiry_date: Optional[StrictInt] = Field(...)
    binding: Optional[Binding] = Field(...)
    __properties = ["access_mode", "unlock_type", "unlock_days", "unlock_weekday", "unlock_weekdays", "unlock_date", "expiry_type", "expiry_days", "expiry_date", "binding"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> RuleBodyOut:
        """Create an instance of RuleBodyOut from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if access_mode (nullable) is None
        # and __fields_set__ contains the field
        if self.access_mode is None and "access_mode" in self.__fields_set__:
            _dict['access_mode'] = None

        # set to None if unlock_type (nullable) is None
        # and __fields_set__ contains the field
        if self.unlock_type is None and "unlock_type" in self.__fields_set__:
            _dict['unlock_type'] = None

        # set to None if unlock_days (nullable) is None
        # and __fields_set__ contains the field
        if self.unlock_days is None and "unlock_days" in self.__fields_set__:
            _dict['unlock_days'] = None

        # set to None if unlock_weekday (nullable) is None
        # and __fields_set__ contains the field
        if self.unlock_weekday is None and "unlock_weekday" in self.__fields_set__:
            _dict['unlock_weekday'] = None

        # set to None if unlock_weekdays (nullable) is None
        # and __fields_set__ contains the field
        if self.unlock_weekdays is None and "unlock_weekdays" in self.__fields_set__:
            _dict['unlock_weekdays'] = None

        # set to None if unlock_date (nullable) is None
        # and __fields_set__ contains the field
        if self.unlock_date is None and "unlock_date" in self.__fields_set__:
            _dict['unlock_date'] = None

        # set to None if expiry_type (nullable) is None
        # and __fields_set__ contains the field
        if self.expiry_type is None and "expiry_type" in self.__fields_set__:
            _dict['expiry_type'] = None

        # set to None if expiry_days (nullable) is None
        # and __fields_set__ contains the field
        if self.expiry_days is None and "expiry_days" in self.__fields_set__:
            _dict['expiry_days'] = None

        # set to None if expiry_date (nullable) is None
        # and __fields_set__ contains the field
        if self.expiry_date is None and "expiry_date" in self.__fields_set__:
            _dict['expiry_date'] = None

        # set to None if binding (nullable) is None
        # and __fields_set__ contains the field
        if self.binding is None and "binding" in self.__fields_set__:
            _dict['binding'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> RuleBodyOut:
        """Create an instance of RuleBodyOut from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return RuleBodyOut.parse_obj(obj)

        _obj = RuleBodyOut.parse_obj({
            "access_mode": obj.get("access_mode"),
            "unlock_type": obj.get("unlock_type"),
            "unlock_days": obj.get("unlock_days"),
            "unlock_weekday": obj.get("unlock_weekday"),
            "unlock_weekdays": obj.get("unlock_weekdays"),
            "unlock_date": obj.get("unlock_date"),
            "expiry_type": obj.get("expiry_type"),
            "expiry_days": obj.get("expiry_days"),
            "expiry_date": obj.get("expiry_date"),
            "binding": obj.get("binding")
        })
        return _obj





# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictInt, StrictStr

class ProductLinkOut(BaseModel):
    """
    ProductLinkOut
    """
    id: StrictInt = Field(...)
    marketplace_product_id: StrictInt = Field(...)
    provider: Optional[StrictStr] = Field(...)
    external_product_id: Optional[StrictStr] = Field(...)
    __properties = ["id", "marketplace_product_id", "provider", "external_product_id"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ProductLinkOut:
        """Create an instance of ProductLinkOut from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if provider (nullable) is None
        # and __fields_set__ contains the field
        if self.provider is None and "provider" in self.__fields_set__:
            _dict['provider'] = None

        # set to None if external_product_id (nullable) is None
        # and __fields_set__ contains the field
        if self.external_product_id is None and "external_product_id" in self.__fields_set__:
            _dict['external_product_id'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ProductLinkOut:
        """Create an instance of ProductLinkOut from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ProductLinkOut.parse_obj(obj)

        _obj = ProductLinkOut.parse_obj({
            "id": obj.get("id"),
            "marketplace_product_id": obj.get("marketplace_product_id"),
            "provider": obj.get("provider"),
            "external_product_id": obj.get("external_product_id")
        })
        return _obj





# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from access_server_connector.models.course_tree_out import CourseTreeOut  # noqa: E501

class TestCourseTreeOut(unittest.TestCase):
    """CourseTreeOut unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CourseTreeOut:
        """Test CourseTreeOut
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CourseTreeOut`
        """
        model = CourseTreeOut()  # noqa: E501
        if include_optional:
            return CourseTreeOut(
                course = access_server_connector.models.access_result_out.AccessResultOut(
                    resource_type = 'course', 
                    resource_id = 56, 
                    state = 'available', 
                    allowed = True, 
                    available_at = 56, 
                    expires_at = 56, 
                    lock_reason = null, 
                    winning_layer = null, 
                    reasons = [
                        56
                        ], 
                    expired_message = '', ),
                modules = [
                    access_server_connector.models.module_tree_out.ModuleTreeOut(
                        module = access_server_connector.models.access_result_out.AccessResultOut(
                            resource_type = 'course', 
                            resource_id = 56, 
                            state = 'available', 
                            allowed = True, 
                            available_at = 56, 
                            expires_at = 56, 
                            lock_reason = null, 
                            winning_layer = null, 
                            reasons = [
                                56
                                ], 
                            expired_message = '', ), 
                        lessons = [
                            access_server_connector.models.access_result_out.AccessResultOut(
                                resource_type = 'course', 
                                resource_id = 56, 
                                state = 'available', 
                                allowed = True, 
                                available_at = 56, 
                                expires_at = 56, 
                                lock_reason = null, 
                                winning_layer = null, 
                                reasons = [
                                    56
                                    ], 
                                expired_message = '', )
                            ], )
                    ],
                next_transition = 56
            )
        else:
            return CourseTreeOut(
                course = access_server_connector.models.access_result_out.AccessResultOut(
                    resource_type = 'course', 
                    resource_id = 56, 
                    state = 'available', 
                    allowed = True, 
                    available_at = 56, 
                    expires_at = 56, 
                    lock_reason = null, 
                    winning_layer = null, 
                    reasons = [
                        56
                        ], 
                    expired_message = '', ),
                modules = [
                    access_server_connector.models.module_tree_out.ModuleTreeOut(
                        module = access_server_connector.models.access_result_out.AccessResultOut(
                            resource_type = 'course', 
                            resource_id = 56, 
                            state = 'available', 
                            allowed = True, 
                            available_at = 56, 
                            expires_at = 56, 
                            lock_reason = null, 
                            winning_layer = null, 
                            reasons = [
                                56
                                ], 
                            expired_message = '', ), 
                        lessons = [
                            access_server_connector.models.access_result_out.AccessResultOut(
                                resource_type = 'course', 
                                resource_id = 56, 
                                state = 'available', 
                                allowed = True, 
                                available_at = 56, 
                                expires_at = 56, 
                                lock_reason = null, 
                                winning_layer = null, 
                                reasons = [
                                    56
                                    ], 
                                expired_message = '', )
                            ], )
                    ],
                next_transition = 56,
        )
        """

    def testCourseTreeOut(self):
        """Test CourseTreeOut"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class UnlockType(str, Enum):
    """
    UnlockType
    """

    """
    allowed enum values
    """
    IMMEDIATE = 'immediate'
    AFTER_DAYS = 'after_days'
    ON_WEEKDAY = 'on_weekday'
    AFTER_DAYS_THEN_WEEKDAY = 'after_days_then_weekday'
    FIXED_DATE = 'fixed_date'

    @classmethod
    def from_json(cls, json_str: str) -> UnlockType:
        """Create an instance of UnlockType from a JSON string"""
        return UnlockType(json.loads(json_str))





# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictInt, conlist
from access_server_connector.models.unlock_type import UnlockType

class UnlockSpec(BaseModel):
    """
    UnlockSpec
    """
    type: Optional[UnlockType] = None
    days: Optional[StrictInt] = None
    weekday: Optional[StrictInt] = None
    weekdays: Optional[conlist(StrictInt)] = None
    var_date: Optional[StrictInt] = Field(default=None, alias="date")
    __properties = ["type", "days", "weekday", "weekdays", "date"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> UnlockSpec:
        """Create an instance of UnlockSpec from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if days (nullable) is None
        # and __fields_set__ contains the field
        if self.days is None and "days" in self.__fields_set__:
            _dict['days'] = None

        # set to None if weekday (nullable) is None
        # and __fields_set__ contains the field
        if self.weekday is None and "weekday" in self.__fields_set__:
            _dict['weekday'] = None

        # set to None if weekdays (nullable) is None
        # and __fields_set__ contains the field
        if self.weekdays is None and "weekdays" in self.__fields_set__:
            _dict['weekdays'] = None

        # set to None if var_date (nullable) is None
        # and __fields_set__ contains the field
        if self.var_date is None and "var_date" in self.__fields_set__:
            _dict['date'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> UnlockSpec:
        """Create an instance of UnlockSpec from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return UnlockSpec.parse_obj(obj)

        _obj = UnlockSpec.parse_obj({
            "type": obj.get("type"),
            "days": obj.get("days"),
            "weekday": obj.get("weekday"),
            "weekdays": obj.get("weekdays"),
            "var_date": obj.get("date")
        })
        return _obj





# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from access_server_connector.models.wrapped_response_list_package_out import WrappedResponseListPackageOut  # noqa: E501

class TestWrappedResponseListPackageOut(unittest.TestCase):
    """WrappedResponseListPackageOut unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> WrappedResponseListPackageOut:
        """Test WrappedResponseListPackageOut
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `WrappedResponseListPackageOut`
        """
        model = WrappedResponseListPackageOut()  # noqa: E501
        if include_optional:
            return WrappedResponseListPackageOut(
                done = True,
                result = [
                    access_server_connector.models.package_out.PackageOut(
                        id = 56, 
                        portal_id = 56, 
                        title = '', 
                        payment_type = '', 
                        is_active = True, 
                        is_locked = True, 
                        direct_link_slug = '', 
                        sales_page_url = '', 
                        expired_message = '', 
                        created_at = 56, 
                        updated_at = 56, )
                    ]
            )
        else:
            return WrappedResponseListPackageOut(
                result = [
                    access_server_connector.models.package_out.PackageOut(
                        id = 56, 
                        portal_id = 56, 
                        title = '', 
                        payment_type = '', 
                        is_active = True, 
                        is_locked = True, 
                        direct_link_slug = '', 
                        sales_page_url = '', 
                        expired_message = '', 
                        created_at = 56, 
                        updated_at = 56, )
                    ],
        )
        """

    def testWrappedResponseListPackageOut(self):
        """Test WrappedResponseListPackageOut"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from access_server_connector.api.packages_api import PackagesApi  # noqa: E501


class TestPackagesApi(unittest.IsolatedAsyncioTestCase):
    """PackagesApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = PackagesApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_count_members_v1_packages_access_package_id_members_count_get(self) -> None:
        """Test case for count_members_v1_packages_access_package_id_members_count_get

        Count members who have access to this package  # noqa: E501
        """
        pass

    async def test_count_packages_v1_packages_count_get(self) -> None:
        """Test case for count_packages_v1_packages_count_get

        Count a portal's access packages  # noqa: E501
        """
        pass

    async def test_create_package_v1_packages_post(self) -> None:
        """Test case for create_package_v1_packages_post

        Create an access package  # noqa: E501
        """
        pass

    async def test_delete_package_v1_packages_access_package_id_delete(self) -> None:
        """Test case for delete_package_v1_packages_access_package_id_delete

        Delete an access package  # noqa: E501
        """
        pass

    async def test_delete_rule_v1_packages_access_package_id_rules_rule_id_delete(self) -> None:
        """Test case for delete_rule_v1_packages_access_package_id_rules_rule_id_delete

        Remove an access rule from a package  # noqa: E501
        """
        pass

    async def test_get_package_by_slug_v1_packages_by_slug_slug_get(self) -> None:
        """Test case for get_package_by_slug_v1_packages_by_slug_slug_get

        Get public package data by its direct-link slug (unauthenticated)  # noqa: E501
        """
        pass

    async def test_get_package_v1_packages_access_package_id_get(self) -> None:
        """Test case for get_package_v1_packages_access_package_id_get

        Get a single access package (with its rules)  # noqa: E501
        """
        pass

    async def test_get_rules_v1_packages_access_package_id_rules_get(self) -> None:
        """Test case for get_rules_v1_packages_access_package_id_rules_get

        List a package's access rules  # noqa: E501
        """
        pass

    async def test_link_product_v1_packages_access_package_id_products_put(self) -> None:
        """Test case for link_product_v1_packages_access_package_id_products_put

        Link a marketplace product to a package  # noqa: E501
        """
        pass

    async def test_list_members_v1_packages_access_package_id_members_get(self) -> None:
        """Test case for list_members_v1_packages_access_package_id_members_get

        List members who have access to this package (paginated)  # noqa: E501
        """
        pass

    async def test_list_packages_v1_packages_get(self) -> None:
        """Test case for list_packages_v1_packages_get

        List a portal's access packages (paginated)  # noqa: E501
        """
        pass

    async def test_list_product_links_v1_packages_access_package_id_products_get(self) -> None:
        """Test case for list_product_links_v1_packages_access_package_id_products_get

        List the marketplace products linked to a package  # noqa: E501
        """
        pass

    async def test_patch_package_v1_packages_access_package_id_patch(self) -> None:
        """Test case for patch_package_v1_packages_access_package_id_patch

        Toggle is_active / is_locked  # noqa: E501
        """
        pass

    async def test_set_rule_v1_packages_access_package_id_rules_put(self) -> None:
        """Test case for set_rule_v1_packages_access_package_id_rules_put

        Set an access rule on a package  # noqa: E501
        """
        pass

    async def test_unlink_product_v1_packages_access_package_id_products_link_id_delete(self) -> None:
        """Test case for unlink_product_v1_packages_access_package_id_products_link_id_delete

        Unlink a marketplace product from a package  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class ReasonKind(str, Enum):
    """
    ReasonKind
    """

    """
    allowed enum values
    """
    ORDER = 'order'
    MANUAL = 'manual'
    REWARD = 'reward'
    FREE = 'free'

    @classmethod
    def from_json(cls, json_str: str) -> ReasonKind:
        """Create an instance of ReasonKind from a JSON string"""
        return ReasonKind(json.loads(json_str))





# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from access_server_connector.api.access_api import AccessApi  # noqa: E501


class TestAccessApi(unittest.IsolatedAsyncioTestCase):
    """AccessApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = AccessApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_check_v1_access_check_post(self) -> None:
        """Test case for check_v1_access_check_post

        Check a single resource  # noqa: E501
        """
        pass

    async def test_courses_summary_v1_access_members_member_id_courses_get(self) -> None:
        """Test case for courses_summary_v1_access_members_member_id_courses_get

        List a member's course access summary  # noqa: E501
        """
        pass

    async def test_resolve_v1_access_resolve_post(self) -> None:
        """Test case for resolve_v1_access_resolve_post

        Resolve a resource tree  # noqa: E501
        """
        pass

    async def test_tree_v1_access_members_member_id_courses_course_id_tree_post(self) -> None:
        """Test case for tree_v1_access_members_member_id_courses_course_id_tree_post

        Resolve a course access tree  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from access_server_connector.models.access_mode import AccessMode
from access_server_connector.models.access_order_event import AccessOrderEvent
from access_server_connector.models.access_result_out import AccessResultOut
from access_server_connector.models.binding import Binding
from access_server_connector.models.check_in import CheckIn
from access_server_connector.models.consume_out import ConsumeOut
from access_server_connector.models.course_structure import CourseStructure
from access_server_connector.models.course_summary_out import CourseSummaryOut
from access_server_connector.models.course_tree_out import CourseTreeOut
from access_server_connector.models.deactivate_in import DeactivateIn
from access_server_connector.models.event_order import EventOrder
from access_server_connector.models.event_product import EventProduct
from access_server_connector.models.event_subscription import EventSubscription
from access_server_connector.models.expiry_type import ExpiryType
from access_server_connector.models.grant_in import GrantIn
from access_server_connector.models.http_validation_error import HTTPValidationError
from access_server_connector.models.health_out import HealthOut
from access_server_connector.models.id_out import IdOut
from access_server_connector.models.lesson_structure import LessonStructure
from access_server_connector.models.location_inner import LocationInner
from access_server_connector.models.lock_reason import LockReason
from access_server_connector.models.member_ownership_out import MemberOwnershipOut
from access_server_connector.models.module_structure import ModuleStructure
from access_server_connector.models.module_tree_out import ModuleTreeOut
from access_server_connector.models.node_access_out import NodeAccessOut
from access_server_connector.models.override_batch_in import OverrideBatchIn
from access_server_connector.models.override_item import OverrideItem
from access_server_connector.models.override_out import OverrideOut
from access_server_connector.models.owned_package_out import OwnedPackageOut
from access_server_connector.models.ownership_reason_out import OwnershipReasonOut
from access_server_connector.models.package_detail_out import PackageDetailOut
from access_server_connector.models.package_in import PackageIn
from access_server_connector.models.package_out import PackageOut
from access_server_connector.models.package_patch_in import PackagePatchIn
from access_server_connector.models.package_rule_in import PackageRuleIn
from access_server_connector.models.product_link_in import ProductLinkIn
from access_server_connector.models.product_link_out import ProductLinkOut
from access_server_connector.models.public_package_out import PublicPackageOut
from access_server_connector.models.reason_kind import ReasonKind
from access_server_connector.models.reason_status import ReasonStatus
from access_server_connector.models.resolve_in import ResolveIn
from access_server_connector.models.resolve_out import ResolveOut
from access_server_connector.models.resource_node_in import ResourceNodeIn
from access_server_connector.models.resource_type import ResourceType
from access_server_connector.models.rule_body import RuleBody
from access_server_connector.models.rule_body_out import RuleBodyOut
from access_server_connector.models.rule_out import RuleOut
from access_server_connector.models.state import State
from access_server_connector.models.tree_in import TreeIn
from access_server_connector.models.unlock_spec import UnlockSpec
from access_server_connector.models.unlock_type import UnlockType
from access_server_connector.models.validation_error import ValidationError
from access_server_connector.models.winning_layer import WinningLayer
from access_server_connector.models.wrapped_response_access_result_out import WrappedResponseAccessResultOut
from access_server_connector.models.wrapped_response_consume_out import WrappedResponseConsumeOut
from access_server_connector.models.wrapped_response_course_tree_out import WrappedResponseCourseTreeOut
from access_server_connector.models.wrapped_response_health_out import WrappedResponseHealthOut
from access_server_connector.models.wrapped_response_id_out import WrappedResponseIdOut
from access_server_connector.models.wrapped_response_int import WrappedResponseInt
from access_server_connector.models.wrapped_response_list_course_summary_out import WrappedResponseListCourseSummaryOut
from access_server_connector.models.wrapped_response_list_member_ownership_out import WrappedResponseListMemberOwnershipOut
from access_server_connector.models.wrapped_response_list_override_out import WrappedResponseListOverrideOut
from access_server_connector.models.wrapped_response_list_owned_package_out import WrappedResponseListOwnedPackageOut
from access_server_connector.models.wrapped_response_list_ownership_reason_out import WrappedResponseListOwnershipReasonOut
from access_server_connector.models.wrapped_response_list_package_out import WrappedResponseListPackageOut
from access_server_connector.models.wrapped_response_list_product_link_out import WrappedResponseListProductLinkOut
from access_server_connector.models.wrapped_response_list_rule_out import WrappedResponseListRuleOut
from access_server_connector.models.wrapped_response_package_detail_out import WrappedResponsePackageDetailOut
from access_server_connector.models.wrapped_response_public_package_out import WrappedResponsePublicPackageOut
from access_server_connector.models.wrapped_response_resolve_out import WrappedResponseResolveOut
from access_server_connector.models.wrapped_response_written_out import WrappedResponseWrittenOut
from access_server_connector.models.written_out import WrittenOut



# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from access_server_connector.api.ownership_api import OwnershipApi  # noqa: E501


class TestOwnershipApi(unittest.IsolatedAsyncioTestCase):
    """OwnershipApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = OwnershipApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_deactivate_v1_ownership_reasons_reason_id_deactivate_post(self) -> None:
        """Test case for deactivate_v1_ownership_reasons_reason_id_deactivate_post

        Deactivate (revoke) an ownership reason  # noqa: E501
        """
        pass

    async def test_grant_v1_ownership_grant_post(self) -> None:
        """Test case for grant_v1_ownership_grant_post

        Manually grant an access package  # noqa: E501
        """
        pass

    async def test_member_packages_count_v1_ownership_members_member_id_packages_count_get(self) -> None:
        """Test case for member_packages_count_v1_ownership_members_member_id_packages_count_get

        Count the access packages a member owns  # noqa: E501
        """
        pass

    async def test_member_packages_v1_ownership_members_member_id_packages_get(self) -> None:
        """Test case for member_packages_v1_ownership_members_member_id_packages_get

        List the access packages a member owns (paginated)  # noqa: E501
        """
        pass

    async def test_ownership_list_v1_ownership_members_member_id_reasons_get(self) -> None:
        """Test case for ownership_list_v1_ownership_members_member_id_reasons_get

        List a member's ownership reasons  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from access_server_connector.models.resolve_in import ResolveIn  # noqa: E501

class TestResolveIn(unittest.TestCase):
    """ResolveIn unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResolveIn:
        """Test ResolveIn
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResolveIn`
        """
        model = ResolveIn()  # noqa: E501
        if include_optional:
            return ResolveIn(
                portal_id = 56,
                member_id = 56,
                structure = access_server_connector.models.resource_node_in.ResourceNodeIn(
                    resource_type = 'course', 
                    resource_id = 56, 
                    is_published = True, 
                    default_unlock = null, 
                    children = [
                        access_server_connector.models.resource_node_in.ResourceNodeIn(
                            resource_type = 'course', 
                            resource_id = 56, 
                            is_published = True, 
                            default_unlock = null, 
                            children = [
                                
                                ], )
                        ], )
            )
        else:
            return ResolveIn(
                portal_id = 56,
                member_id = 56,
                structure = access_server_connector.models.resource_node_in.ResourceNodeIn(
                    resource_type = 'course', 
                    resource_id = 56, 
                    is_published = True, 
                    default_unlock = null, 
                    children = [
                        access_server_connector.models.resource_node_in.ResourceNodeIn(
                            resource_type = 'course', 
                            resource_id = 56, 
                            is_published = True, 
                            default_unlock = null, 
                            children = [
                                
                                ], )
                        ], ),
        )
        """

    def testResolveIn(self):
        """Test ResolveIn"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from access_server_connector.models.event_subscription import EventSubscription  # noqa: E501

class TestEventSubscription(unittest.TestCase):
    """EventSubscription unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> EventSubscription:
        """Test EventSubscription
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `EventSubscription`
        """
        model = EventSubscription()  # noqa: E501
        if include_optional:
            return EventSubscription(
                external_subscription_id = '',
                current_period_end = 56,
                grace_until = 56
            )
        else:
            return EventSubscription(
        )
        """

    def testEventSubscription(self):
        """Test EventSubscription"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from access_server_connector.models.module_structure import ModuleStructure  # noqa: E501

class TestModuleStructure(unittest.TestCase):
    """ModuleStructure unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ModuleStructure:
        """Test ModuleStructure
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ModuleStructure`
        """
        model = ModuleStructure()  # noqa: E501
        if include_optional:
            return ModuleStructure(
                module_id = 56,
                is_published = True,
                default_unlock = access_server_connector.models.unlock_spec.UnlockSpec(
                    type = null, 
                    days = 56, 
                    weekday = 56, 
                    weekdays = [
                        56
                        ], 
                    date = 56, ),
                lessons = [
                    access_server_connector.models.lesson_structure.LessonStructure(
                        lesson_id = 56, 
                        is_published = True, 
                        default_unlock = null, )
                    ]
            )
        else:
            return ModuleStructure(
                module_id = 56,
        )
        """

    def testModuleStructure(self):
        """Test ModuleStructure"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class WinningLayer(str, Enum):
    """
    WinningLayer
    """

    """
    allowed enum values
    """
    OVERRIDE = 'override'
    AP_RULE = 'ap_rule'
    COURSE_DEFAULT = 'course_default'

    @classmethod
    def from_json(cls, json_str: str) -> WinningLayer:
        """Create an instance of WinningLayer from a JSON string"""
        return WinningLayer(json.loads(json_str))





# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictInt, StrictStr, conlist
from access_server_connector.models.event_order import EventOrder
from access_server_connector.models.event_product import EventProduct
from access_server_connector.models.event_subscription import EventSubscription
from access_server_connector.models.reason_kind import ReasonKind
from access_server_connector.models.reason_status import ReasonStatus

class AccessOrderEvent(BaseModel):
    """
    AccessOrderEvent
    """
    event_id: StrictStr = Field(...)
    occurred_at: StrictInt = Field(...)
    portal_id: StrictInt = Field(...)
    member_id: StrictInt = Field(...)
    reason_kind: Optional[ReasonKind] = None
    product: Optional[EventProduct] = None
    access_package_ids: Optional[conlist(StrictInt)] = None
    order: Optional[EventOrder] = None
    status: ReasonStatus = Field(...)
    status_reason: Optional[StrictStr] = None
    subscription: Optional[EventSubscription] = None
    __properties = ["event_id", "occurred_at", "portal_id", "member_id", "reason_kind", "product", "access_package_ids", "order", "status", "status_reason", "subscription"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> AccessOrderEvent:
        """Create an instance of AccessOrderEvent from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of product
        if self.product:
            _dict['product'] = self.product.to_dict()
        # override the default output from pydantic by calling `to_dict()` of order
        if self.order:
            _dict['order'] = self.order.to_dict()
        # override the default output from pydantic by calling `to_dict()` of subscription
        if self.subscription:
            _dict['subscription'] = self.subscription.to_dict()
        # set to None if product (nullable) is None
        # and __fields_set__ contains the field
        if self.product is None and "product" in self.__fields_set__:
            _dict['product'] = None

        # set to None if access_package_ids (nullable) is None
        # and __fields_set__ contains the field
        if self.access_package_ids is None and "access_package_ids" in self.__fields_set__:
            _dict['access_package_ids'] = None

        # set to None if order (nullable) is None
        # and __fields_set__ contains the field
        if self.order is None and "order" in self.__fields_set__:
            _dict['order'] = None

        # set to None if status_reason (nullable) is None
        # and __fields_set__ contains the field
        if self.status_reason is None and "status_reason" in self.__fields_set__:
            _dict['status_reason'] = None

        # set to None if subscription (nullable) is None
        # and __fields_set__ contains the field
        if self.subscription is None and "subscription" in self.__fields_set__:
            _dict['subscription'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> AccessOrderEvent:
        """Create an instance of AccessOrderEvent from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return AccessOrderEvent.parse_obj(obj)

        _obj = AccessOrderEvent.parse_obj({
            "event_id": obj.get("event_id"),
            "occurred_at": obj.get("occurred_at"),
            "portal_id": obj.get("portal_id"),
            "member_id": obj.get("member_id"),
            "reason_kind": obj.get("reason_kind"),
            "product": EventProduct.from_dict(obj.get("product")) if obj.get("product") is not None else None,
            "access_package_ids": obj.get("access_package_ids"),
            "order": EventOrder.from_dict(obj.get("order")) if obj.get("order") is not None else None,
            "status": obj.get("status"),
            "status_reason": obj.get("status_reason"),
            "subscription": EventSubscription.from_dict(obj.get("subscription")) if obj.get("subscription") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from access_server_connector.models.wrapped_response_list_ownership_reason_out import WrappedResponseListOwnershipReasonOut  # noqa: E501

class TestWrappedResponseListOwnershipReasonOut(unittest.TestCase):
    """WrappedResponseListOwnershipReasonOut unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> WrappedResponseListOwnershipReasonOut:
        """Test WrappedResponseListOwnershipReasonOut
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `WrappedResponseListOwnershipReasonOut`
        """
        model = WrappedResponseListOwnershipReasonOut()  # noqa: E501
        if include_optional:
            return WrappedResponseListOwnershipReasonOut(
                done = True,
                result = [
                    access_server_connector.models.ownership_reason_out.OwnershipReasonOut(
                        id = 56, 
                        access_package_id = 56, 
                        kind = 'order', 
                        status = 'active', 
                        granted_at = 56, 
                        is_test = True, )
                    ]
            )
        else:
            return WrappedResponseListOwnershipReasonOut(
                result = [
                    access_server_connector.models.ownership_reason_out.OwnershipReasonOut(
                        id = 56, 
                        access_package_id = 56, 
                        kind = 'order', 
                        status = 'active', 
                        granted_at = 56, 
                        is_test = True, )
                    ],
        )
        """

    def testWrappedResponseListOwnershipReasonOut(self):
        """Test WrappedResponseListOwnershipReasonOut"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from access_server_connector.models.member_ownership_out import MemberOwnershipOut  # noqa: E501

class TestMemberOwnershipOut(unittest.TestCase):
    """MemberOwnershipOut unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> MemberOwnershipOut:
        """Test MemberOwnershipOut
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `MemberOwnershipOut`
        """
        model = MemberOwnershipOut()  # noqa: E501
        if include_optional:
            return MemberOwnershipOut(
                member_id = 56,
                reason_id = 56,
                access_package_id = 56,
                kind = 'order',
                status = 'active',
                granted_at = 56,
                is_test = True,
                period_end = 56,
                grace_until = 56
            )
        else:
            return MemberOwnershipOut(
                member_id = 56,
                reason_id = 56,
                access_package_id = 56,
                kind = 'order',
                status = 'active',
                granted_at = 56,
                is_test = True,
                period_end = 56,
                grace_until = 56,
        )
        """

    def testMemberOwnershipOut(self):
        """Test MemberOwnershipOut"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictInt, conlist
from access_server_connector.models.access_result_out import AccessResultOut
from access_server_connector.models.module_tree_out import ModuleTreeOut

class CourseTreeOut(BaseModel):
    """
    CourseTreeOut
    """
    course: AccessResultOut = Field(...)
    modules: conlist(ModuleTreeOut) = Field(...)
    next_transition: Optional[StrictInt] = Field(...)
    __properties = ["course", "modules", "next_transition"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CourseTreeOut:
        """Create an instance of CourseTreeOut from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of course
        if self.course:
            _dict['course'] = self.course.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in modules (list)
        _items = []
        if self.modules:
            for _item in self.modules:
                if _item:
                    _items.append(_item.to_dict())
            _dict['modules'] = _items
        # set to None if next_transition (nullable) is None
        # and __fields_set__ contains the field
        if self.next_transition is None and "next_transition" in self.__fields_set__:
            _dict['next_transition'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CourseTreeOut:
        """Create an instance of CourseTreeOut from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return CourseTreeOut.parse_obj(obj)

        _obj = CourseTreeOut.parse_obj({
            "course": AccessResultOut.from_dict(obj.get("course")) if obj.get("course") is not None else None,
            "modules": [ModuleTreeOut.from_dict(_item) for _item in obj.get("modules")] if obj.get("modules") is not None else None,
            "next_transition": obj.get("next_transition")
        })
        return _obj





# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from access_server_connector.models.wrapped_response_package_detail_out import WrappedResponsePackageDetailOut  # noqa: E501

class TestWrappedResponsePackageDetailOut(unittest.TestCase):
    """WrappedResponsePackageDetailOut unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> WrappedResponsePackageDetailOut:
        """Test WrappedResponsePackageDetailOut
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `WrappedResponsePackageDetailOut`
        """
        model = WrappedResponsePackageDetailOut()  # noqa: E501
        if include_optional:
            return WrappedResponsePackageDetailOut(
                done = True,
                result = access_server_connector.models.package_detail_out.PackageDetailOut(
                    id = 56, 
                    portal_id = 56, 
                    title = '', 
                    payment_type = '', 
                    is_active = True, 
                    is_locked = True, 
                    direct_link_slug = '', 
                    sales_page_url = '', 
                    expired_message = '', 
                    created_at = 56, 
                    updated_at = 56, 
                    rules = [
                        access_server_connector.models.rule_out.RuleOut(
                            id = 56, 
                            resource_type = 'course', 
                            resource_id = 56, 
                            access_mode = 'available', 
                            unlock_type = 'immediate', 
                            unlock_days = 56, 
                            unlock_weekday = 56, 
                            unlock_weekdays = [
                                56
                                ], 
                            unlock_date = 56, 
                            expiry_type = 'none', 
                            expiry_days = 56, 
                            expiry_date = 56, 
                            binding = 'lifetime', )
                        ], )
            )
        else:
            return WrappedResponsePackageDetailOut(
                result = access_server_connector.models.package_detail_out.PackageDetailOut(
                    id = 56, 
                    portal_id = 56, 
                    title = '', 
                    payment_type = '', 
                    is_active = True, 
                    is_locked = True, 
                    direct_link_slug = '', 
                    sales_page_url = '', 
                    expired_message = '', 
                    created_at = 56, 
                    updated_at = 56, 
                    rules = [
                        access_server_connector.models.rule_out.RuleOut(
                            id = 56, 
                            resource_type = 'course', 
                            resource_id = 56, 
                            access_mode = 'available', 
                            unlock_type = 'immediate', 
                            unlock_days = 56, 
                            unlock_weekday = 56, 
                            unlock_weekdays = [
                                56
                                ], 
                            unlock_date = 56, 
                            expiry_type = 'none', 
                            expiry_days = 56, 
                            expiry_date = 56, 
                            binding = 'lifetime', )
                        ], ),
        )
        """

    def testWrappedResponsePackageDetailOut(self):
        """Test WrappedResponsePackageDetailOut"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
